//   Copyright 2020 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

#ifndef DISPLAY_A_MAP_H
#define DISPLAY_A_MAP_H

namespace Esri
{
namespace ArcGISRuntime
{

class Map;
class MapQuickView;

class GraphicsOverlay;
class Graphic;
class LocatorTask;
class GeocodeResult;
class SuggestResult;
class TextSymbol;

}
}
#include <QObject>

#include <QAbstractListModel>
#include "GeocodeParameters.h"

class Display_a_map : public QObject
{
  Q_OBJECT
  Q_PROPERTY(Esri::ArcGISRuntime::MapQuickView* mapView READ mapView WRITE setMapView NOTIFY mapViewChanged)

  Q_PROPERTY(QAbstractListModel* suggestions READ suggestions NOTIFY suggestionsChanged)

public:
  explicit Display_a_map(QObject* parent = nullptr);
  ~Display_a_map() override;

  Q_INVOKABLE void geocode(const QString& query);
  Q_INVOKABLE void clearGraphics();
  Q_INVOKABLE void setSuggestions(const QString& text);

signals:
  void mapViewChanged();

  void suggestionsChanged();
  void hideSuggestionView();

private:
  Esri::ArcGISRuntime::MapQuickView* mapView() const;
  void setMapView(Esri::ArcGISRuntime::MapQuickView* mapView);
  void setupViewpoint();

  void setupLocatorTask();

  Esri::ArcGISRuntime::Map* m_map = nullptr;
  Esri::ArcGISRuntime::MapQuickView* m_mapView = nullptr;

  void configureGraphic();
  QAbstractListModel* suggestions() const;
  Esri::ArcGISRuntime::GraphicsOverlay* m_graphicsOverlay = nullptr;
  Esri::ArcGISRuntime::LocatorTask* m_locatorTask = nullptr;
  Esri::ArcGISRuntime::Graphic* m_graphicResultLocation = nullptr;
  Esri::ArcGISRuntime::Graphic* m_graphicResultText = nullptr;
  Esri::ArcGISRuntime::TextSymbol* m_textSymbol = nullptr;
  QAbstractListModel* m_suggestListModel = nullptr;
  Esri::ArcGISRuntime::GeocodeParameters m_geocodeParams;

};

#endif // DISPLAY_A_MAP_H

